@@ -33,7 +33,6 @@ from gettext import gettext as _
 
 from kazam.utils import *
 from kazam.backend.prefs import *
-from kazam.backend.constants import *
 from kazam.backend.grabber import Grabber
 from kazam.frontend.main_menu import MainMenu
 from kazam.frontend.window_area import AreaWindow
@@ -43,6 +42,7 @@ from kazam.frontend.about_dialog import AboutDialog
 from kazam.frontend.indicator import KazamIndicator
 from kazam.frontend.window_select import SelectWindow
 from kazam.frontend.done_recording import DoneRecording
+from kazam.frontend.window_outline import OutlineWindow
 from kazam.frontend.window_countdown import CountdownWindow
 
 logger = logging.getLogger("Main")
@@ -54,7 +54,7 @@ try:
     from gi.repository import Gst
     gst_gi = Gst.version()
     if not gst_gi[0]:
-        logger.critical("Gstreamer 1.0 or higher requred, bailing out.")
+        logger.critical(_("Gstreamer 1.0 or higher required, bailing out."))
         gst_gi = None
         sys.exit(0)
     else:
@@ -63,9 +63,10 @@ try:
                                                                       gst_gi[2],
                                                                       gst_gi[3]))
 except ImportError:
-    logger.critical("Gstreamer 1.0 or higher requred, bailing out.")
+    logger.critical(_("Gstreamer 1.0 or higher required, bailing out."))
     sys.exit(0)
 
+
 class KazamApp(GObject.GObject):
 
     def __init__(self, datadir, dist, debug, test, sound, silent):
@@ -80,8 +81,7 @@ class KazamApp(GObject.GObject):
         prefs.test = test
         prefs.dist = dist
         prefs.silent = silent
-        prefs.sound = not sound     # Parameter is called nosound and if true, then we don't have sound.
-                                    # Tricky parameters are tricky!
+        prefs.sound = sound
 
         self.setup_translations()
 
@@ -94,31 +94,7 @@ class KazamApp(GObject.GObject):
                 prefs.sound = False
 
         self.icons = Gtk.IconTheme.get_default()
-        self.icons.append_search_path(os.path.join(prefs.datadir,"icons", "48x48", "apps"))
-        self.icons.append_search_path(os.path.join(prefs.datadir,"icons", "16x16", "apps"))
-
-        try:
-            from gi.repository import Unity, Dbusmenu
-            launcher = Unity.LauncherEntry.get_for_desktop_id("kazam.desktop")
-            ql = Dbusmenu.Menuitem.new()
-            ql_item1 = Dbusmenu.Menuitem.new()
-            ql_item1.property_set(Dbusmenu.MENUITEM_PROP_LABEL, _("Record screencast"))
-            ql_item1.property_set_bool(Dbusmenu.MENUITEM_PROP_VISIBLE, True)
-            ql_item1.connect("item-activated", self.cb_ql_screencast)
-            ql.child_append(ql_item1)
-            ql_item2 = Dbusmenu.Menuitem.new()
-            ql_item2.property_set(Dbusmenu.MENUITEM_PROP_LABEL, _("Take screenshot"))
-            ql_item2.property_set_bool(Dbusmenu.MENUITEM_PROP_VISIBLE, True)
-            ql_item2.connect("item-activated", self.cb_ql_screenshot)
-            ql.child_append(ql_item2)
-            ql_item3 = Dbusmenu.Menuitem.new()
-            ql_item3.property_set(Dbusmenu.MENUITEM_PROP_LABEL, _("Preferences"))
-            ql_item3.property_set_bool(Dbusmenu.MENUITEM_PROP_VISIBLE, True)
-            ql_item3.connect("item-activated", self.cb_ql_preferences)
-            ql.child_append(ql_item3)
-            launcher.set_property("quicklist", ql)
-        except ImportError:
-            logger.warning("Unity and Dbusmenu not found. Skipping launcher integration.")
+        self.default_cursor = Gdk.Cursor(Gdk.CursorType.LEFT_PTR)
 
         # Initialize all the variables
 
@@ -128,6 +104,8 @@ class KazamApp(GObject.GObject):
         self.tempfile = ""
         self.recorder = None
         self.area_window = None
+        self.select_window = None
+        self.outline_window = None
         self.old_vid_path = None
         self.old_pic_path = None
         self.in_countdown = False
@@ -173,17 +151,27 @@ class KazamApp(GObject.GObject):
             else:
                 logger.debug("Unable to get name for '%s'" % w)
 
-        # Main Menu
+        # Retrieve gdk_win for the root window
+        self.gdk_win = self.window.get_root_window()
+
+        #
+        # Attach main menu, so that
+        #
         self.MainGrid.attach(self.mainmenu.menubar, 0, 0, 1, 1)
 
-        self.context = self.toolbar_main.get_style_context()
-        self.context.add_class(Gtk.STYLE_CLASS_PRIMARY_TOOLBAR)
+        self.main_context = self.toolbar_main.get_style_context()
+        self.main_context.add_class(Gtk.STYLE_CLASS_PRIMARY_TOOLBAR)
+        self.main_context.connect("changed", self.cb_main_context_change)
+        self.main_fg_color = self.main_context.get_color(Gtk.StateFlags.ACTIVE)
 
         self.btn_cast = Gtk.RadioToolButton(group=None)
         self.btn_cast.set_label(_("Screencast"))
         self.btn_cast.set_tooltip_text(_("Record a video of your desktop."))
-        img1 = Gtk.Image.new_from_file(os.path.join(prefs.datadir, "icons", "light", "screencast.png"))
-        self.btn_cast.set_icon_widget(img1)
+        cast_icon = self.icons.lookup_icon("kazam-screencast-symbolic", 24, Gtk.IconLookupFlags.FORCE_SIZE)
+        if cast_icon:
+            cast_icon_pixbuf, was_sym = cast_icon.load_symbolic(self.main_fg_color, None, None, None)
+            cast_img  = Gtk.Image.new_from_pixbuf(cast_icon_pixbuf)
+            self.btn_cast.set_icon_widget(cast_img)
         self.btn_cast.set_active(True)
         self.btn_cast.set_name("MAIN_SCREENCAST")
         self.btn_cast.connect("toggled", self.cb_main_toggled)
@@ -191,8 +179,11 @@ class KazamApp(GObject.GObject):
         self.btn_shot = Gtk.RadioToolButton(group=self.btn_cast)
         self.btn_shot.set_label(_("Screenshot"))
         self.btn_shot.set_tooltip_text(_("Record a picture of your desktop."))
-        img2 = Gtk.Image.new_from_file(os.path.join(prefs.datadir, "icons", "light", "screenshot-1.png"))
-        self.btn_shot.set_icon_widget(img2)
+        shot_icon = self.icons.lookup_icon("kazam-screenshot-symbolic", 24, Gtk.IconLookupFlags.FORCE_SIZE)
+        if shot_icon:
+            shot_icon_pixbuf, was_sym = shot_icon.load_symbolic(self.main_fg_color, None, None, None)
+            shot_img  = Gtk.Image.new_from_pixbuf(shot_icon_pixbuf)
+            self.btn_shot.set_icon_widget(shot_img)
         self.btn_shot.set_name("MAIN_SCREENSHOT")
         self.btn_shot.connect("toggled", self.cb_main_toggled)
 
@@ -205,11 +196,18 @@ class KazamApp(GObject.GObject):
         self.toolbar_main.insert(self.sep_1, -1)
 
         # Auxiliary toolbar
+        self.aux_context = self.toolbar_aux.get_style_context()
+        self.aux_context.add_class(Gtk.STYLE_CLASS_TOOLBAR)
+        self.aux_fg_color = self.aux_context.get_color(Gtk.StateFlags.ACTIVE)
+
         self.btn_full = Gtk.RadioToolButton(group=None)
         self.btn_full.set_label(_("Fullscreen"))
         self.btn_full.set_tooltip_text(_("Capture contents of the current screen."))
-        img3 = Gtk.Image.new_from_file(os.path.join(prefs.datadir, "icons", "dark", "fullscreen.png"))
-        self.btn_full.set_icon_widget(img3)
+        full_icon = self.icons.lookup_icon("kazam-fullscreen-symbolic", 24, Gtk.IconLookupFlags.FORCE_SIZE)
+        if full_icon:
+            full_icon_pixbuf, was_sym = full_icon.load_symbolic(self.aux_fg_color, None, None, None)
+            full_img  = Gtk.Image.new_from_pixbuf(full_icon_pixbuf)
+            self.btn_full.set_icon_widget(full_img)
         self.btn_full.set_active(True)
         self.btn_full.set_name("MODE_FULL")
         self.btn_full.connect("toggled", self.cb_record_mode_toggled)
@@ -217,16 +215,24 @@ class KazamApp(GObject.GObject):
         self.btn_allscreens = Gtk.RadioToolButton(group=self.btn_full)
         self.btn_allscreens.set_label(_("All Screens"))
         self.btn_allscreens.set_tooltip_text(_("Capture contents of all of your screens."))
-        img4 = Gtk.Image.new_from_file(os.path.join(prefs.datadir, "icons", "dark", "all-screens.png"))
-        self.btn_allscreens.set_icon_widget(img4)
+        allscreens_icon = self.icons.lookup_icon("kazam-all-screens-symbolic", 24, Gtk.IconLookupFlags.FORCE_SIZE)
+        if allscreens_icon:
+            allscreens_icon_pixbuf, was_sym = allscreens_icon.load_symbolic(self.aux_fg_color, None, None, None)
+            allscreens_img  = Gtk.Image.new_from_pixbuf(allscreens_icon_pixbuf)
+            self.btn_allscreens.set_icon_widget(allscreens_img)
         self.btn_allscreens.set_name("MODE_ALL")
         self.btn_allscreens.connect("toggled", self.cb_record_mode_toggled)
+        if HW.combined_screen is None:
+            self.btn_allscreens.set_sensitive(False)
 
         self.btn_window = Gtk.RadioToolButton(group=self.btn_full)
         self.btn_window.set_label(_("Window"))
         self.btn_window.set_tooltip_text(_("Capture contents of a single window."))
-        img5 = Gtk.Image.new_from_file(os.path.join(prefs.datadir, "icons", "dark", "window.png"))
-        self.btn_window.set_icon_widget(img5)
+        window_icon = self.icons.lookup_icon("kazam-window-symbolic", 24, Gtk.IconLookupFlags.FORCE_SIZE)
+        if window_icon:
+            window_icon_pixbuf, was_sym = window_icon.load_symbolic(self.aux_fg_color, None, None, None)
+            window_img  = Gtk.Image.new_from_pixbuf(window_icon_pixbuf)
+            self.btn_window.set_icon_widget(window_img)
         self.btn_window.set_name("MODE_WIN")
         self.btn_window.connect("toggled", self.cb_record_mode_toggled)
         self.btn_window.connect("clicked", self.cb_record_window_clicked)
@@ -234,8 +240,11 @@ class KazamApp(GObject.GObject):
         self.btn_area = Gtk.RadioToolButton(group=self.btn_full)
         self.btn_area.set_label(_("Area"))
         self.btn_area.set_tooltip_text(_("Capture a pre-selected area of your screen."))
-        img6 = Gtk.Image.new_from_file(os.path.join(prefs.datadir, "icons", "dark", "area.png"))
-        self.btn_area.set_icon_widget(img6)
+        area_icon = self.icons.lookup_icon("kazam-area-symbolic", 24, Gtk.IconLookupFlags.FORCE_SIZE)
+        if area_icon:
+            area_icon_pixbuf, was_sym = area_icon.load_symbolic(self.aux_fg_color, None, None, None)
+            area_img  = Gtk.Image.new_from_pixbuf(area_icon_pixbuf)
+            self.btn_area.set_icon_widget(area_img)
         self.btn_area.set_name("MODE_AREA")
         self.btn_area.connect("toggled", self.cb_record_mode_toggled)
         self.btn_area.connect("clicked", self.cb_record_area_clicked)
@@ -243,14 +252,15 @@ class KazamApp(GObject.GObject):
         self.sep_2 = Gtk.SeparatorToolItem()
         self.sep_2.set_draw(False)
         self.sep_2.set_expand(True)
-        #self.toolbar_aux.insert(self.sep_2, -1)
+        self.toolbar_aux.insert(self.sep_2, -1)
         self.toolbar_aux.insert(self.btn_full, -1)
         self.toolbar_aux.insert(self.btn_allscreens, -1)
         self.toolbar_aux.insert(self.btn_window, -1)
         self.toolbar_aux.insert(self.btn_area, -1)
-        #self.toolbar_aux.insert(self.sep_2, -1)
+        self.toolbar_aux.insert(self.sep_2, -1)
 
         self.ntb_main.set_current_page(0)
+        self.btn_record.grab_focus()
 
         #
         # Take care of screen size changes.
@@ -272,16 +282,10 @@ class KazamApp(GObject.GObject):
                         """  SUPER-CTRL-F to finish recording.\n"""
                         """  SUPER-CTRL-P to pause/resume recording.\n"""
                         """  SUPER-CTRL-Q to quit.\n"""
-                       )
+                        )
 
         self.restore_UI()
 
-        if not prefs.sound:
-            self.combobox_audio.set_sensitive(False)
-            self.combobox_audio2.set_sensitive(False)
-            self.volumebutton_audio.set_sensitive(False)
-            self.volumebutton_audio2.set_sensitive(False)
-
         HW.get_current_screen(self.window)
         self.startup = False
 
@@ -308,6 +312,10 @@ class KazamApp(GObject.GObject):
             if self.record_mode == MODE_WIN:
                 self.last_mode.set_active(True)
             self.indicator.menuitem_start.set_label(_("Take screenshot"))
+            if self.record_mode == "MODE_WIN":
+                self.chk_borders_pic.set_sensitive(True)
+            else:
+                self.chk_borders_pic.set_sensitive(False)
 
     #
     # Record mode toggles
@@ -347,15 +355,72 @@ class KazamApp(GObject.GObject):
             self.tmp_sig3 = self.select_window.connect("window-selected", self.cb_window_selected)
             self.tmp_sig4 = self.select_window.connect("window-canceled", self.cb_window_canceled)
             self.record_mode = MODE_WIN
+            self.chk_borders_pic.set_sensitive(True)
 
         if widget.get_name() == "MODE_WIN" and not widget.get_active():
             logger.debug("Window capture OFF.")
+            self.chk_borders_pic.set_sensitive(False)
             if self.select_window:
                 self.select_window.disconnect(self.tmp_sig3)
                 self.select_window.disconnect(self.tmp_sig4)
                 self.select_window.window.destroy()
                 self.select_window = None
 
+    def cb_main_context_change(self, widget):
+        #
+        # If this is the only way on how to deal with symbolic icons, then someone needs spanking ...
+        #
+        if widget.get_state() == Gtk.StateFlags.BACKDROP:
+            self.main_fg_color = self.main_context.get_color(Gtk.StateFlags.ACTIVE)
+            self.aux_fg_color = self.aux_context.get_color(Gtk.StateFlags.ACTIVE)
+
+            #
+            # Update icons on the main toolbar
+            #
+            cast_icon = self.icons.lookup_icon("kazam-screencast-symbolic", 24, Gtk.IconLookupFlags.FORCE_SIZE)
+            if cast_icon:
+                cast_icon_pixbuf, was_sym = cast_icon.load_symbolic(self.main_fg_color, None, None, None)
+                cast_img = Gtk.Image.new_from_pixbuf(cast_icon_pixbuf)
+                self.btn_cast.set_icon_widget(cast_img)
+                cast_img.show_all()
+
+            shot_icon = self.icons.lookup_icon("kazam-screenshot-symbolic", 24, Gtk.IconLookupFlags.FORCE_SIZE)
+            if shot_icon:
+                shot_icon_pixbuf, was_sym = shot_icon.load_symbolic(self.main_fg_color, None, None, None)
+                shot_img = Gtk.Image.new_from_pixbuf(shot_icon_pixbuf)
+                self.btn_shot.set_icon_widget(shot_img)
+                shot_img.show_all()
+
+            #
+            # Update icons on the aux toolbar
+            #
+            full_icon = self.icons.lookup_icon("kazam-fullscreen-symbolic", 24, Gtk.IconLookupFlags.FORCE_SIZE)
+            if full_icon:
+                full_icon_pixbuf, was_sym = full_icon.load_symbolic(self.aux_fg_color, None, None, None)
+                full_img = Gtk.Image.new_from_pixbuf(full_icon_pixbuf)
+                self.btn_full.set_icon_widget(full_img)
+                full_img.show_all()
+
+            allscreens_icon = self.icons.lookup_icon("kazam-all-screens-symbolic", 24, Gtk.IconLookupFlags.FORCE_SIZE)
+            if allscreens_icon:
+                allscreens_icon_pixbuf, was_sym = allscreens_icon.load_symbolic(self.aux_fg_color, None, None, None)
+                allscreens_img = Gtk.Image.new_from_pixbuf(allscreens_icon_pixbuf)
+                self.btn_allscreens.set_icon_widget(allscreens_img)
+                allscreens_img.show_all()
+
+            window_icon = self.icons.lookup_icon("kazam-window-symbolic", 24, Gtk.IconLookupFlags.FORCE_SIZE)
+            if window_icon:
+                window_icon_pixbuf, was_sym = window_icon.load_symbolic(self.aux_fg_color, None, None, None)
+                window_img = Gtk.Image.new_from_pixbuf(window_icon_pixbuf)
+                self.btn_window.set_icon_widget(window_img)
+                window_img.show_all()
+
+            area_icon = self.icons.lookup_icon("kazam-area-symbolic", 24, Gtk.IconLookupFlags.FORCE_SIZE)
+            if area_icon:
+                area_icon_pixbuf, was_sym = area_icon.load_symbolic(self.aux_fg_color, None, None, None)
+                area_img = Gtk.Image.new_from_pixbuf(area_icon_pixbuf)
+                self.btn_area.set_icon_widget(area_img)
+                area_img.show_all()
 
     #
     # Unity quick list callbacks
@@ -371,10 +436,6 @@ class KazamApp(GObject.GObject):
         self.btn_shot.set_active(True)
         self.run_counter()
 
-    def cb_ql_preferences(self, menu, data):
-        logger.debug("Preferences quicklist activated.")
-        self.cb_preferences_request(None)
-
     def cb_record_area_clicked(self, widget):
         if self.area_window:
             logger.debug("Area mode clicked.")
@@ -393,13 +454,18 @@ class KazamApp(GObject.GObject):
             self.area_window.starty,
             self.area_window.endx,
             self.area_window.endy))
+        logger.debug("Area selected: GX: {0}, GY: {1}, GX: {2}, GY: {3}".format(
+            self.area_window.g_startx,
+            self.area_window.g_starty,
+            self.area_window.g_endx,
+            self.area_window.g_endy))
+        prefs.area = (self.area_window.g_startx,
+                      self.area_window.g_starty,
+                      self.area_window.g_endx,
+                      self.area_window.g_endy,
+                      self.area_window.width,
+                      self.area_window.height)
         self.window.set_sensitive(True)
-        prefs.area = (self.area_window.startx,
-                     self.area_window.starty,
-                     self.area_window.endx,
-                     self.area_window.endy,
-                     self.area_window.width,
-                     self.area_window.height)
 
     def cb_area_canceled(self, widget):
         logger.debug("Area selection canceled.")
@@ -422,14 +488,13 @@ class KazamApp(GObject.GObject):
         logger.debug("Screen size changed.")
         HW.get_screens()
         #
-        # I combined screen was set to none, turn off the button for all screens
+        # If combined screen was set to none, turn off the button for all screens
         #
         if HW.combined_screen:
             self.btn_allscreens.set_sensitive(True)
         else:
             self.btn_allscreens.set_sensitive(False)
 
-
     def cb_configure_event(self, widget, event):
         if event.type == Gdk.EventType.CONFIGURE:
             prefs.main_x = event.x
@@ -437,6 +502,8 @@ class KazamApp(GObject.GObject):
 
     def cb_quit_request(self, indicator):
         logger.debug("Quit requested.")
+        # Restore cursor, just in case if by some chance stays set to cross-hairs
+        self.gdk_win.set_cursor(self.default_cursor)
         (prefs.main_x, prefs.main_y) = self.window.get_position()
         try:
             os.remove(self.recorder.tempfile)
@@ -502,6 +569,12 @@ class KazamApp(GObject.GObject):
 
     def cb_stop_request(self, widget):
         self.recording = False
+
+        if self.outline_window:
+            self.outline_window.hide()
+            self.outline_window.window.destroy()
+            self.outline_window = None
+
         if self.in_countdown:
             logger.debug("Cancel countdown request.")
             self.countdown.cancel_countdown()
@@ -522,7 +595,7 @@ class KazamApp(GObject.GObject):
     def cb_flush_done(self, widget):
         if self.main_mode == MODE_SCREENCAST and prefs.autosave_video:
             logger.debug("Autosaving enabled.")
-            fname = get_next_filename(prefs.video_dest,
+            fname = get_next_filename(prefs.autosave_video_dir,
                                       prefs.autosave_video_file,
                                       CODEC_LIST[prefs.codec][3])
 
@@ -545,22 +618,27 @@ class KazamApp(GObject.GObject):
             self.window.set_sensitive(False)
 
         elif self.main_mode == MODE_SCREENSHOT:
+            if self.outline_window:
+                self.outline_window.hide()
+                self.outline_window.window.destroy()
+                self.outline_window = None
+
             self.grabber.connect("save-done", self.cb_save_done)
             self.indicator.recording = False
             self.indicator.menuitem_start.set_sensitive(True)
             self.indicator.menuitem_pause.set_sensitive(False)
             self.indicator.menuitem_pause.set_active(False)
             self.indicator.menuitem_finish.set_sensitive(False)
-            self.indicator.menuitem_show.set_sensitive(True)
             self.indicator.menuitem_quit.set_sensitive(True)
 
             if prefs.autosave_picture:
-                fname = get_next_filename(prefs.picture_dest, prefs.autosave_picture_file, ".png")
+                fname = get_next_filename(prefs.autosave_picture_dir,
+                                          prefs.autosave_picture_file,
+                                          ".png")
                 self.grabber.autosave(fname)
             else:
                 self.grabber.save_capture(self.old_pic_path)
 
-
     def cb_pause_request(self, widget):
         logger.debug("Pause requested.")
         self.recording_paused = True
@@ -605,8 +683,7 @@ class KazamApp(GObject.GObject):
         (command, arg_list) = data
         arg_list.insert(0, command)
         #
-        # Even if we're not autosaving get the next autosave file and move currently recorded file there
-        # In case user might lost it.
+        # Use the current autosave filename for edit file.
         #
         fname = get_next_filename(prefs.video_dest,
                                   prefs.autosave_video_file,
@@ -618,7 +695,7 @@ class KazamApp(GObject.GObject):
         try:
             Popen(arg_list)
         except:
-            logger.warning("Failed to open selected editor. Have no ")
+            logger.warning("Failed to open selected editor.")
         self.window.set_sensitive(True)
         self.window.show_all()
 
@@ -663,7 +740,6 @@ class KazamApp(GObject.GObject):
         self.indicator.menuitem_start.set_sensitive(False)
         self.indicator.menuitem_pause.set_sensitive(False)
         self.indicator.menuitem_finish.set_sensitive(True)
-        self.indicator.menuitem_show.set_sensitive(False)
         self.indicator.menuitem_quit.set_sensitive(False)
         self.indicator.menuitem_finish.set_label(_("Cancel countdown"))
         self.in_countdown = True
@@ -671,15 +747,24 @@ class KazamApp(GObject.GObject):
         self.indicator.blink_set_state(BLINK_START)
 
         if self.main_mode == MODE_SCREENCAST and prefs.sound:
-            if prefs.capture_speakers and prefs.audio_source > 0:
-                audio_source = prefs.audio_sources[prefs.audio_source][1]
+            if prefs.capture_speakers:
+                try:
+                    audio_source = prefs.speaker_sources[prefs.audio_source][1]
+                except  IndexError:
+                    logger.warning("It appears that speakers audio source isn't set up correctly.")
+                    audio_source = None
             else:
                 audio_source = None
 
-            if prefs.capture_microphone and prefs.audio2_source > 0:
-                audio2_source = prefs.audio_sources[prefs.audio2_source][1]
+            if prefs.capture_microphone:
+                try:
+                    audio2_source = prefs.mic_sources[prefs.audio2_source][1]
+                except IndexError:
+                    logger.warning("It appears that microphone audio source isn't set up correctly.")
+                    audio2_source = None
             else:
                 audio2_source = None
+
         else:
             audio_source = None
             audio2_source = None
@@ -690,11 +775,11 @@ class KazamApp(GObject.GObject):
 
         video_source = None
 
-        if self.record_mode == MODE_FULL:
+        if self.record_mode == MODE_ALL:
+            video_source = HW.combined_screen
+        else:
             screen = HW.get_current_screen(self.window)
             video_source = HW.screens[screen]
-        else:
-            video_source = HW.combined_screen
 
         if self.main_mode == MODE_SCREENCAST:
             self.recorder = Screencast()
@@ -713,13 +798,25 @@ class KazamApp(GObject.GObject):
                                        prefs.xid if self.record_mode == MODE_WIN else None)
             self.grabber.connect("flush-done", self.cb_flush_done)
 
-
         self.countdown = CountdownWindow(self.indicator, show_window = prefs.countdown_splash)
         self.countdown.connect("counter-finished", self.cb_counter_finished)
         self.countdown.run(prefs.countdown_timer)
         self.recording = True
         logger.debug("Hiding main window.")
         self.window.hide()
+        try:
+            if self.record_mode == MODE_AREA and prefs.area:
+                if prefs.dist[0] == 'Ubuntu' and int(prefs.dist[1].split(".")[0]) > 12:
+                    logger.debug("Showing recording outline.")
+                    self.outline_window = OutlineWindow(prefs.area[0],
+                                                        prefs.area[1],
+                                                        prefs.area[4],
+                                                        prefs.area[5])
+                    self.outline_window.show()
+                else:
+                    logger.debug("Ubuntu 13.04 or higher not detected, recording outline not shown.")
+        except:
+                logger.debug("Unable to show recording outline.")
 
     def setup_translations(self):
         gettext.bindtextdomain("kazam", "/usr/share/locale")
@@ -729,7 +826,6 @@ class KazamApp(GObject.GObject):
         except Exception as e:
             logger.exception("EXCEPTION: Setlocale failed, no language support.")
 
-
     def restore_UI (self):
         self.window.move(prefs.main_x, prefs.main_y)
         self.chk_cursor.set_active(prefs.capture_cursor)
