@@ -21,7 +21,7 @@
 
 import os
 import logging
-logger = logging.getLogger("GStreamer-GI")
+logger = logging.getLogger("GStreamer")
 
 import tempfile
 import multiprocessing
@@ -35,22 +35,24 @@ os.putenv("GST_DEBUG_DUMP_DOT_DIR", "/tmp")
 from gi.repository import GObject, Gst
 
 from kazam.backend.prefs import *
-from kazam.backend.constants import *
+
 
 GObject.threads_init()
 Gst.init(None)
-Gst.debug_set_active(True)
+if prefs.debug:
+    Gst.debug_set_active(True)
+else:
+    Gst.debug_set_active(False)
+
 
 class Screencast(GObject.GObject):
-    __gsignals__ = {
-        "flush-done" : (GObject.SIGNAL_RUN_LAST,
-                        None,
-                        (),
-            ),
-        }
+    __gsignals__ = {"flush-done": (GObject.SIGNAL_RUN_LAST,
+                    None,
+                    (),),
+                    }
+
     def __init__(self):
         GObject.GObject.__init__(self)
-
         self.temp_fh = tempfile.mkstemp(prefix="kazam_", dir=prefs.video_dest, suffix=".movie")
         self.tempfile = self.temp_fh[1]
         self.muxer_tempfile = "{0}.mux".format(self.tempfile)
@@ -66,7 +68,6 @@ class Screencast(GObject.GObject):
                       area,
                       xid):
 
-
         # Get the number of cores available then use all except one for encoding
         self.cores = multiprocessing.cpu_count()
 
@@ -79,23 +80,19 @@ class Screencast(GObject.GObject):
         self.area = area
         self.xid = xid
 
-        logger.debug("audio_source : {0}".format(audio_source))
-        logger.debug("video_source: {0}".format(video_source))
-        logger.debug("xid: {0}".format(xid))
-        logger.debug("area: {0}".format(area))
+        logger.debug("Audio_source : {0}".format(audio_source))
+        logger.debug("Audio2_source : {0}".format(audio2_source))
+        logger.debug("Video_source: {0}".format(video_source))
+        logger.debug("Xid: {0}".format(xid))
+        logger.debug("Area: {0}".format(area))
 
         logger.debug("Capture Cursor: {0}".format(prefs.capture_cursor))
         logger.debug("Framerate : {0}".format(prefs.framerate))
-        logger.debug("Codec: {0}".format(CODEC_LIST[prefs.codec][1]))
 
         if self.video_source or self.area:
             self.setup_video_source()
 
-        if self.audio_source:
-            self.setup_audio_source()
-
-        if self.audio2_source:
-            self.setup_audio2_source()
+        self.setup_audio_sources()
 
         self.setup_filesink()
         self.setup_pipeline()
@@ -141,10 +138,8 @@ class Screencast(GObject.GObject):
 
         if prefs.test:
             logger.info("Using test signal instead of screen capture.")
-            self.vid_caps = Gst.caps_from_string("video/x-raw,format=(x-raw-rgb),framerate={0}/1, width={1}, height={2}".format(
-                  prefs.framerate,
-                  endx - startx,
-                  endy - starty))
+            self.vid_caps = Gst.caps_from_string("video/x-raw, framerate={0}/1".format(
+                  int(prefs.framerate)))
             self.vid_caps_filter = Gst.ElementFactory.make("capsfilter", "vid_filter")
             self.vid_caps_filter.set_property("caps", self.vid_caps)
         else:
@@ -170,9 +165,9 @@ class Screencast(GObject.GObject):
             self.videosrc.set_property("use-damage", False)
             self.videosrc.set_property("show-pointer", prefs.capture_cursor)
 
-        self.vid_caps = Gst.caps_from_string("video/x-raw,format=(x-raw-rgb),framerate={0}/1".format(prefs.framerate))
-        self.vid_caps_filter = Gst.ElementFactory.make("capsfilter", "vid_filter")
-        self.vid_caps_filter.set_property("caps", self.vid_caps)
+            self.vid_caps = Gst.caps_from_string("video/x-raw, framerate={0}/1".format(int(prefs.framerate)))
+            self.vid_caps_filter = Gst.ElementFactory.make("capsfilter", "vid_filter")
+            self.vid_caps_filter.set_property("caps", self.vid_caps)
 
         self.videoconvert = Gst.ElementFactory.make("videoconvert", "videoconvert")
         self.videorate = Gst.ElementFactory.make("videorate", "video_rate")
@@ -192,6 +187,15 @@ class Screencast(GObject.GObject):
             self.videnc.set_property("token-partitions", 2)
             self.videnc.set_property("max-quantizer", 30)
             self.videnc.set_property("threads", self.cores)
+
+            # Good framerate, bad memory
+            #self.videnc.set_property("cpu-used", 6)
+            #self.videnc.set_property("deadline", 1000000)
+            #self.videnc.set_property("min-quantizer", 15)
+            #self.videnc.set_property("max-quantizer", 15)
+            #self.videnc.set_property("threads", self.cores)
+
+
             self.mux = Gst.ElementFactory.make("webmmux", "muxer")
         elif prefs.codec == CODEC_H264:
             self.videnc.set_property("speed-preset", "ultrafast")
@@ -214,34 +218,40 @@ class Screencast(GObject.GObject):
         self.vid_in_queue = Gst.ElementFactory.make("queue", "queue_v1")
         self.vid_out_queue = Gst.ElementFactory.make("queue", "queue_v2")
 
-    def setup_audio_source(self):
-        logger.debug("Audio1 Source:\n  {0}".format(self.audio_source))
-        self.audiosrc = Gst.ElementFactory.make("pulsesrc", "audio_src")
-        self.audiosrc.set_property("device", self.audio_source)
-        self.aud_caps = Gst.caps_from_string("audio/x-raw")
-        self.aud_caps_filter = Gst.ElementFactory.make("capsfilter", "aud_filter")
-        self.aud_caps_filter.set_property("caps", self.aud_caps)
-        self.audioconv = Gst.ElementFactory.make("audioconvert", "audio_conv")
-        if prefs.codec == CODEC_VP8:
-            self.audioenc = Gst.ElementFactory.make("vorbisenc", "audio_encoder")
-            self.audioenc.set_property("quality", 1)
-        else:
-            self.audioenc = Gst.ElementFactory.make("lamemp3enc", "audio_encoder")
-            self.audioenc.set_property("quality", 0)
+    def setup_audio_sources(self):
+        if self.audio_source or self.audio2_source:
+            logger.debug("Setup audio elements.")
+            self.aud_out_queue = Gst.ElementFactory.make("queue", "queue_a_out")
+            self.audioconv = Gst.ElementFactory.make("audioconvert", "audio_conv")
+            if prefs.codec == CODEC_VP8:
+                self.audioenc = Gst.ElementFactory.make("vorbisenc", "audio_encoder")
+                self.audioenc.set_property("quality", 1)
+            else:
+                self.audioenc = Gst.ElementFactory.make("lamemp3enc", "audio_encoder")
+                self.audioenc.set_property("quality", 0)
 
-        self.aud_in_queue = Gst.ElementFactory.make("queue", "queue_a_in")
-        self.aud_out_queue = Gst.ElementFactory.make("queue", "queue_a_out")
+        if self.audio_source:
+            logger.debug("Audio1 Source:\n  {0}".format(self.audio_source))
+            self.audiosrc = Gst.ElementFactory.make("pulsesrc", "audio_src")
+            self.audiosrc.set_property("device", self.audio_source)
+            self.aud_caps = Gst.caps_from_string("audio/x-raw")
+            self.aud_caps_filter = Gst.ElementFactory.make("capsfilter", "aud_filter")
+            self.aud_caps_filter.set_property("caps", self.aud_caps)
 
-    def setup_audio2_source(self):
-        logger.debug("Audio2 Source:\n  {0}".format(self.audio2_source))
-        self.audiomixer = Gst.ElementFactory.make("adder", "audiomixer")
-        self.audio2src = Gst.ElementFactory.make("pulsesrc", "audio2_src")
-        self.audio2src.set_property("device", self.audio2_source)
-        self.aud2_caps = Gst.caps_from_string("audio/x-raw")
-        self.aud2_caps_filter = Gst.ElementFactory.make("capsfilter", "aud2_filter")
-        self.aud2_caps_filter.set_property("caps", self.aud2_caps)
-        self.aud2_in_queue = Gst.ElementFactory.make("queue", "queue_a2_in")
-        self.audio2conv = Gst.ElementFactory.make("audioconvert", "audio2_conv")
+            self.aud_in_queue = Gst.ElementFactory.make("queue", "queue_a_in")
+
+        if self.audio2_source:
+            logger.debug("Audio2 Source:\n  {0}".format(self.audio2_source))
+            self.audio2src = Gst.ElementFactory.make("pulsesrc", "audio2_src")
+            self.audio2src.set_property("device", self.audio2_source)
+            self.aud2_caps = Gst.caps_from_string("audio/x-raw")
+            self.aud2_caps_filter = Gst.ElementFactory.make("capsfilter", "aud2_filter")
+            self.aud2_caps_filter.set_property("caps", self.aud2_caps)
+            self.aud2_in_queue = Gst.ElementFactory.make("queue", "queue_a2_in")
+            self.audio2conv = Gst.ElementFactory.make("audioconvert", "audio2_conv")
+
+        if self.audio_source and self.audio2_source:
+            self.audiomixer = Gst.ElementFactory.make("adder", "audiomixer")
 
     def setup_filesink(self):
         logger.debug("Filesink: {0}".format(self.tempfile))
@@ -269,20 +279,24 @@ class Screencast(GObject.GObject):
         if prefs.codec is not CODEC_RAW:
             self.pipeline.add(self.videnc)
 
+        if self.audio_source or self.audio2_source:
+            self.pipeline.add(self.audioconv)
+            self.pipeline.add(self.audioenc)
+            self.pipeline.add(self.aud_out_queue)
+
         if self.audio_source:
             self.pipeline.add(self.audiosrc)
             self.pipeline.add(self.aud_in_queue)
             self.pipeline.add(self.aud_caps_filter)
-            self.pipeline.add(self.aud_out_queue)
-            self.pipeline.add(self.audioconv)
-            self.pipeline.add(self.audioenc)
 
         if self.audio2_source:
-            self.pipeline.add(self.audiomixer)
-            self.pipeline.add(self.aud2_in_queue)
             self.pipeline.add(self.audio2src)
+            self.pipeline.add(self.aud2_in_queue)
             self.pipeline.add(self.aud2_caps_filter)
 
+        if self.audio_source and self.audio2_source:
+            self.pipeline.add(self.audiomixer)
+
         self.pipeline.add(self.mux)
         self.pipeline.add(self.sink)
 
@@ -312,36 +326,54 @@ class Screencast(GObject.GObject):
 
         self.vid_out_queue.link(self.mux)
 
-        if self.audio_source:
+        if self.audio_source and self.audio2_source:
             logger.debug("Linking Audio")
             ret = self.audiosrc.link(self.aud_in_queue)
             logger.debug(" Link audiosrc -> aud_in_queue: %s" % ret)
             ret = self.aud_in_queue.link(self.aud_caps_filter)
             logger.debug(" Link aud_in_queue -> aud_caps_filter: %s" % ret)
 
-            if self.audio2_source:
-                logger.debug("Linking Audio2")
-                # Link first audio source to mixer
-                ret = self.aud_caps_filter.link(self.audiomixer)
-                logger.debug(" Link aud_caps_filter -> audiomixer: %s" % ret)
+            logger.debug("Linking Audio2")
+            # Link first audio source to mixer
+            ret = self.aud_caps_filter.link(self.audiomixer)
+            logger.debug(" Link aud_caps_filter -> audiomixer: %s" % ret)
 
-                # Link second audio source to mixer
-                ret = self.audio2src.link(self.aud2_in_queue)
-                logger.debug(" Link audio2src -> aud2_in_queue: %s" % ret)
-                ret = self.aud2_in_queue.link(self.aud2_caps_filter)
-                logger.debug(" Link aud2_in_queue -> aud2_caps_filter: %s" % ret)
-                ret = self.aud2_caps_filter.link(self.audiomixer)
-                logger.debug(" Link aud2_caps_filter -> audiomixer: %s" % ret)
+            # Link second audio source to mixer
+            ret = self.audio2src.link(self.aud2_in_queue)
+            logger.debug(" Link audio2src -> aud2_in_queue: %s" % ret)
+            ret = self.aud2_in_queue.link(self.aud2_caps_filter)
+            logger.debug(" Link aud2_in_queue -> aud2_caps_filter: %s" % ret)
+            ret = self.aud2_caps_filter.link(self.audiomixer)
+            logger.debug(" Link aud2_caps_filter -> audiomixer: %s" % ret)
 
-                # Link mixer to audio convert
-                ret = self.audiomixer.link(self.audioconv)
-                logger.debug(" Link audiomixer -> audioconv: %s" % ret)
+            # Link mixer to audio convert
+            ret = self.audiomixer.link(self.audioconv)
+            logger.debug(" Link audiomixer -> audioconv: %s" % ret)
 
-            else:
-                # Link first audio source to audio convert
-                ret = self.aud_caps_filter.link(self.audioconv)
-                logger.debug(" Link aud_caps_filter -> audioconv: %s" % ret)
+        elif self.audio_source:
 
+            logger.debug("Linking Audio")
+            ret = self.audiosrc.link(self.aud_in_queue)
+            logger.debug(" Link audiosrc -> aud_in_queue: %s" % ret)
+            ret = self.aud_in_queue.link(self.aud_caps_filter)
+            logger.debug(" Link aud_in_queue -> aud_caps_filter: %s" % ret)
+
+            # Link first audio source to audio convert
+            ret = self.aud_caps_filter.link(self.audioconv)
+            logger.debug(" Link aud_caps_filter -> audioconv: %s" % ret)
+
+        elif self.audio2_source:
+            # Link second audio source to mixer
+            ret = self.audio2src.link(self.aud2_in_queue)
+            logger.debug(" Link audio2src -> aud2_in_queue: %s" % ret)
+            ret = self.aud2_in_queue.link(self.aud2_caps_filter)
+            logger.debug(" Link aud2_in_queue -> aud2_caps_filter: %s" % ret)
+
+            # Link second audio source to audio convert
+            ret = self.aud2_caps_filter.link(self.audioconv)
+            logger.debug(" Link aud2_caps_filter -> audioconv: %s" % ret)
+
+        if self.audio_source or self.audio2_source:
             # Link audio to muxer
             ret = self.audioconv.link(self.audioenc)
             logger.debug("Link audioconv -> audioenc: %s" % ret)
@@ -386,31 +418,3 @@ class Screencast(GObject.GObject):
             self.emit("flush-done")
         elif t == Gst.MessageType.ERROR:
             logger.debug("Received an error message: %s", message.parse_error()[1])
-
-
-def detect_codecs():
-    codecs_supported = []
-    codec_test = None
-    for codec in CODEC_LIST:
-        if codec[0]:
-            try:
-                codec_test = Gst.ElementFactory.make(codec[1], "video_encoder")
-            except:
-                logger.info("Unable to find {0} GStreamer plugin - support disabled.".format(codec))
-                codec_test = None
-
-            if codec_test:
-                codecs_supported.append(codec[0])
-                logger.info("Supported encoder: {0}.".format(codec[2]))
-        else:
-            # RAW codec is None, so we don't try to load it.
-            codecs_supported.append(codec[0])
-            logger.info("Supported encoder: {0}.".format(codec[2]))
-        codec_test = None
-    return codecs_supported
-
-def get_codec(codec):
-    for c in CODEC_LIST:
-        if c[0] == codec:
-            return c
-    return None
