@@ -27,6 +27,7 @@ from gi.repository import Gtk, GdkPixbuf, GObject
 
 from kazam.backend.prefs import *
 
+
 class EditComboBox(Gtk.ComboBox):
 
     KDENLIVE_VERSION = [0,8]
@@ -34,20 +35,20 @@ class EditComboBox(Gtk.ComboBox):
     #
     # This really needs to be done differently ...
     #
-    if prefs.dist[2] == 'quantal':
+    if prefs.dist[2] == 'quantal' or prefs.dist[2] == 'raring':
         EDITORS = {
                     "/usr/share/app-install/desktop/openshot:openshot.desktop":[],
-                    "/usr/share/app-install/desktop/pitivi:pitivi.desktop":["-i", "-a"],
-                    "/usr/share/app-install/desktop/avidemux:avidemux-gtk.desktop":[],
-                    "/usr/share/app-install/desktop/kdenlive:kde4__kdenlive.desktop":["-i"],
-            }
+                    "/usr/share/app-install/desktop/pitivi:pitivi.desktop": ["-i", "-a"],
+                    "/usr/share/app-install/desktop/avidemux:avidemux-gtk.desktop": [],
+                    "/usr/share/app-install/desktop/kdenlive:kde4__kdenlive.desktop": ["-i"],
+        }
     else:
         EDITORS = {
-                   "/usr/share/applications/openshot.desktop":[],
-                   "/usr/share/applications/pitivi.desktop":["-i", "-a"],
-                   "/usr/share/applications/avidemux-gtk.desktop":[],
-                   "/usr/share/applications/kde4/kdenlive.desktop":["-i"],
-                  }
+                    "/usr/share/applications/openshot.desktop": [],
+                    "/usr/share/applications/pitivi.desktop": ["-i", "-a"],
+                    "/usr/share/applications/avidemux-gtk.desktop": [],
+                    "/usr/share/applications/kde4/kdenlive.desktop": ["-i"],
+        }
 
     def __init__(self, icons):
         Gtk.ComboBox.__init__(self)
