@@ -24,9 +24,9 @@ import logging
 logger = logging.getLogger("Indicator")
 
 from gettext import gettext as _
-from gi.repository import Gtk, GObject
+from gi.repository import Gtk, GObject, GLib
 
-from kazam.backend.constants import *
+from kazam.backend.prefs import *
 
 class KazamSuperIndicator(GObject.GObject):
     __gsignals__ = {
@@ -78,14 +78,6 @@ class KazamSuperIndicator(GObject.GObject):
         self.menuitem_finish.connect("activate", self.on_menuitem_finish_activate)
 
         self.menuitem_separator = Gtk.SeparatorMenuItem()
-        self.menuitem_separator2 = Gtk.SeparatorMenuItem()
-
-        self.menuitem_show = Gtk.MenuItem(_("Record setup"))
-        self.menuitem_show.connect("activate", self.on_menuitem_show_activate)
-
-        self.menuitem_about = Gtk.MenuItem(_("About"))
-        self.menuitem_about.connect("activate", self.on_menuitem_about_activate)
-
 
         self.menuitem_quit = Gtk.MenuItem(_("Quit"))
         self.menuitem_quit.connect("activate", self.on_menuitem_quit_activate)
@@ -94,9 +86,6 @@ class KazamSuperIndicator(GObject.GObject):
         self.menu.append(self.menuitem_pause)
         self.menu.append(self.menuitem_finish)
         self.menu.append(self.menuitem_separator)
-        self.menu.append(self.menuitem_show)
-        self.menu.append(self.menuitem_about)
-        self.menu.append(self.menuitem_separator2)
         self.menu.append(self.menuitem_quit)
 
         self.menu.show_all()
@@ -149,19 +138,12 @@ class KazamSuperIndicator(GObject.GObject):
         self.menuitem_pause.set_sensitive(False)
         self.menuitem_pause.set_active(False)
         self.menuitem_finish.set_sensitive(False)
-        self.menuitem_show.set_sensitive(True)
         self.menuitem_quit.set_sensitive(True)
         self.emit("indicator-stop-request")
 
     def on_menuitem_quit_activate(self, menuitem):
         self.emit("indicator-quit-request")
 
-    def on_menuitem_show_activate(self, menuitem):
-        self.emit("indicator-show-request")
-
-    def on_menuitem_about_activate(self, menuitem):
-        self.emit("indicator-about-request")
-
 try:
     from gi.repository import AppIndicator3
 
@@ -210,7 +192,7 @@ try:
                 self.indicator.set_icon("kazam-stopped")
             elif state == BLINK_START:
                 self.blink_state = BLINK_SLOW
-                GObject.timeout_add(500, self.blink)
+                GLib.timeout_add(500, self.blink)
             elif state == BLINK_SLOW:
                 self.blink_state = BLINK_SLOW
             elif state == BLINK_FAST:
@@ -228,9 +210,9 @@ try:
                     self.blink_icon = BLINK_READY_ICON
 
                 if self.blink_state == BLINK_SLOW:
-                    GObject.timeout_add(500, self.blink)
+                    GLib.timeout_add(500, self.blink)
                 elif self.blink_state == BLINK_FAST:
-                    GObject.timeout_add(200, self.blink)
+                    GLib.timeout_add(200, self.blink)
 
         def start_recording(self):
             logger.debug("Recording started.")
@@ -258,12 +240,12 @@ except ImportError:
 
         def cb_indicator_activate(self, widget):
             def position(menu, widget):
-		        return (Gtk.StatusIcon.position_menu(self.menu, widget))
+                return (Gtk.StatusIcon.position_menu(self.menu, widget))
             self.menu.popup(None, None, position, self.indicator, 0, Gtk.get_current_event_time())
 
         def cb_indicator_popup_menu(self, icon, button, time):
             def position(menu, icon):
-		        return (Gtk.StatusIcon.position_menu(self.menu, icon))
+                return (Gtk.StatusIcon.position_menu(self.menu, icon))
             self.menu.popup(None, None, position, self.indicator, button, time)
 
         def on_menuitem_finish_activate(self, menuitem):
@@ -286,7 +268,7 @@ except ImportError:
                 self.indicator.set_from_icon_name("kazam-stopped")
             elif state == BLINK_START:
                 self.blink_state = BLINK_SLOW
-                GObject.timeout_add(500, self.blink)
+                GLib.timeout_add(500, self.blink)
             elif state == BLINK_SLOW:
                 self.blink_state = BLINK_SLOW
             elif state == BLINK_FAST:
@@ -302,10 +284,16 @@ except ImportError:
                     self.blink_icon = BLINK_READY_ICON
 
                 if self.blink_state == BLINK_SLOW:
-                    GObject.timeout_add(500, self.blink)
+                    GLib.timeout_add(500, self.blink)
                 elif self.blink_state == BLINK_FAST:
-                    GObject.timeout_add(200, self.blink)
+                    GLib.timeout_add(200, self.blink)
 
         def start_recording(self):
             logger.debug("Recording started.")
             self.indicator.set_from_icon_name("kazam-recording")
+
+        def hide_it(self):
+            self.indicator.set_visible(False)
+
+        def show_it(self):
+            self.indicator.set_visible(True)
